@@ -1,17 +1,20 @@
-from unsafe.utils.strings import aspx_login, asp_login, php_login, html_login, cgi_login, brf_login, cfm_login, js_login, slash_login, ua
+from unsafe.utils.strings import aspx_login, asp_login, php_login, html_login, cgi_login, brf_login, cfm_login, js_login, slash_login, ua, manager
 import requests
 import random
 from threading import Thread
+from queue import Queue
 
-founded = []
 
 class BruteForcer:
 
     def __init__(self) -> None:
-        pass
-    
-    def send_req_admin_finder(self, domain: str, timeout: int, links: list, user_agent: str | None = None,
-              cookie: str | None = None, proxy: str | None = None, proxies: list | None = None):
+        self.admin_finder_queue = Queue()
+        self.file_manager_queue = Queue()
+        self.admin_finder_founded = []
+        self.file_manager_founded = []
+
+    def send_req_admin_finder(self, domain: str, timeout: int, links_queue, user_agent: str | None = None,
+                              cookie: str | None = None, proxy: str | None = None, proxies: list | None = None):
 
         if "http://" in domain:
             domain = domain.replace("http://", "")
@@ -20,8 +23,8 @@ class BruteForcer:
         else:
             pass
         domain = "http://" + domain
-        global founded
-        for i in links:
+        while not links_queue.empty():
+            i = links_queue.get()
             try:
                 if proxy:
                     proxy = {"http": "http://" +
@@ -58,21 +61,25 @@ class BruteForcer:
                             verify=False,
                         )
                 except Exception as e:
-                    if len(founded) >= 1:
-                        return founded
+                    if len(self.admin_finder_founded) >= 1:
+                        return self.admin_finder_founded
                     else:
-                        return e
+                        return []
+                links_queue.task_done()
                 if r.status_code == 200:
-                    founded.append(full_link)
+                    self.admin_finder_founded.append(full_link)
                 else:
                     pass
             except KeyboardInterrupt:
                 break
-        return founded
+
+        return self.admin_finder_founded
 
     def admin_finder(self, domain: str, workers: int = 3, timeout: int = 10, ext: str = "php", user_agent: str | None = None,
-              cookie: str | None = None, proxy: str | None = None, proxies: list | None = None):
+                     cookie: str | None = None, proxy: str | None = None, proxies: list | None = None):
+        threads = []
         links = []
+        self.admin_finder_founded.clear()
         ext = ext.strip().lower()
         if ext == "php":
             links = php_login
@@ -94,31 +101,94 @@ class BruteForcer:
             links = html_login
         else:
             raise ValueError("This ext(Argument) Not Allowed !")
-        if workers == 1:
-            t = Thread(target=self.send_req_admin_finder, args=(domain, timeout, links, user_agent, cookie, proxy, proxies))
-            t.start()
-            t.join()
-            return founded
-        elif workers == 2:
-            calcu_div = int(len(links) / workers)
-            links1 = links[:calcu_div]
-            links2 = links[calcu_div:]
-            t = Thread(target=self.send_req_admin_finder, args=(domain, timeout, links1, user_agent, cookie, proxy, proxies))
-            t.start()
-            t2 = Thread(target=self.send_req_admin_finder, args=(domain, timeout, links2, user_agent, cookie, proxy, proxies))
-            t2.start()
-            t2.join()
-            return founded
-        elif workers == 3:
-            calcu_div = int(len(links) / workers)
-            links1 = links[:calcu_div]
-            links2 = links[calcu_div:calcu_div*2]
-            links3 = links[calcu_div*2:]
-            t = Thread(target=self.send_req_admin_finder, args=(domain, timeout, links1, user_agent, cookie, proxy, proxies))
-            t.start()
-            t2 = Thread(target=self.send_req_admin_finder, args=(domain, timeout, links2, user_agent, cookie, proxy, proxies))
-            t2.start()
-            t3 = Thread(target=self.send_req_admin_finder, args=(domain, timeout, links3, user_agent, cookie, proxy, proxies))
-            t3.start()
-            t3.join()
-            return founded
\ No newline at end of file
+        for i in links:
+            self.admin_finder_queue.put(i)
+        for i in range(workers):
+            thread_ = Thread(target=self.send_req_admin_finder, args=(
+                domain, timeout, self.admin_finder_queue, user_agent, cookie, proxy, proxies))
+            thread_.setDaemon(True)
+            thread_.start()
+            threads.append(thread_)
+        for i in threads:
+            i.join()
+        return self.admin_finder_founded
+
+    def send_req_file_manager(self, domain: str, timeout: int, links_queue, user_agent: str | None = None,
+                              cookie: str | None = None, proxy: str | None = None, proxies: list | None = None):
+
+        if "http://" in domain:
+            domain = domain.replace("http://", "")
+        elif "https://" in domain:
+            domain = domain.replace("https://", "")
+        else:
+            pass
+
+        domain = "http://" + domain
+        while not links_queue.empty():
+            i = links_queue.get()
+            try:
+                if proxy:
+                    proxy = {"http": "http://" +
+                             str(proxy), "https": "http://" + str(proxy)}
+                elif proxies:
+                    random_proxy = random.choice(proxies)
+                    proxy = {
+                        "http": "http://" + str(random_proxy), "https": "http://" + str(random_proxy)}
+                if not user_agent:
+                    user_agent = random.choice(ua)
+                header = {"User-Agent": user_agent}
+                if cookie:
+                    header.update({"Cookie": cookie})
+                if domain[len(domain) - 1] == "/":
+                    domain = domain[0: len(domain) - 1]
+
+                full_link = domain + i
+                try:
+                    if proxy or proxies:
+                        r = requests.get(
+                            full_link,
+                            headers=header,
+                            allow_redirects=True,
+                            proxies=proxy,
+                            timeout=timeout,
+                            verify=True,
+                        )
+                    else:
+                        r = requests.get(
+                            full_link,
+                            headers=header,
+                            allow_redirects=True,
+                            timeout=timeout,
+                            verify=True,
+                        )
+                except Exception as e:
+                    if len(self.file_manager_founded) >= 1:
+                        return self.file_manager_founded
+                    else:
+                        return []
+                links_queue.task_done()
+                if r.status_code == 200:
+                    self.file_manager_founded.append(f"{r.url}")
+                else:
+                    pass
+            except KeyboardInterrupt:
+                break
+
+        return self.file_manager_founded
+
+    def filemanager_finder(self, domain: str, workers: int = 5, timeout: int = 5, user_agent: str | None = None,
+                           cookie: str | None = None, proxy: str | None = None, proxies: list | None = None):
+        threads = []
+        self.file_manager_founded.clear()
+        for i in manager:
+            self.file_manager_queue.put(i)
+        for i in range(workers):
+            thread_ = Thread(target=self.send_req_file_manager, args=(
+                domain, timeout, self.file_manager_queue, user_agent, cookie, proxy, proxies))
+            thread_.setDaemon(True)
+            thread_.start()
+            threads.append(thread_)
+        for i in threads:
+            i.join()
+
+        return self.file_manager_founded
